# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2016-09-07 21:10
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
    ]
